overrides: Decorator to automatically detect mismatch when overriding a method
==============================================================================

Description
-----------

Decorator to automatically detect mismatch when overriding a method

License
-------

Apache License, Version 2.0

Upstream Contact
----------------

https://pypi.org/project/overrides/

